@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2009 Fabrice Colin
+ *  Copyright 2005-2010 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -274,11 +274,11 @@ void WorkerThread::emitSignal(void)
 unsigned int ThreadsManager::m_nextThreadId = 1;
 
 ThreadsManager::ThreadsManager(const string &defaultIndexLocation,
-	unsigned int maxIndexThreads, unsigned int maxThreadsTime,
-	bool scanLocalFiles) :
+	unsigned int maxThreadsTime, bool scanLocalFiles) :
+	m_mustQuit(false),
 	m_actionQueue(PinotSettings::getInstance().getHistoryDatabaseName(), get_application_name()),
 	m_defaultIndexLocation(defaultIndexLocation),
-	m_maxIndexThreads(maxIndexThreads),
+	m_maxIndexThreads(1),
 	m_backgroundThreadsCount(0),
 	m_foregroundThreadsMaxTime(maxThreadsTime),
 	m_scanLocalFiles(scanLocalFiles),
@@ -288,6 +288,19 @@ ThreadsManager::ThreadsManager(const string &defaultIndexLocation,
 	pthread_rwlock_init(&m_threadsLock, NULL);
 	pthread_rwlock_init(&m_listsLock, NULL);
 
+	// Override the number of indexing threads ?
+	char *pEnvVar = getenv("PINOT_MAXIMUM_INDEX_THREADS");
+	if ((pEnvVar != NULL) &&
+		(strlen(pEnvVar) > 0))
+	{
+		int threadsNum = atoi(pEnvVar);
+
+		if (threadsNum > 0)
+		{
+			m_maxIndexThreads = (unsigned int)threadsNum;
+		}
+	}
+
 #ifdef __OpenBSD__
 	int mib[2], ncpus;
 
@@ -665,6 +678,17 @@ void ThreadsManager::on_thread_signal()
 	m_onThreadEndSignal(pThread);
 }
 
+bool ThreadsManager::mustQuit(bool quit)
+{
+	if (quit == true)
+	{
+		m_mustQuit = true;
+		stop_threads();
+	}
+
+	return m_mustQuit;
+}
+
 ustring ThreadsManager::queue_index(const DocumentInfo &docInfo)
 {
 	bool addToQueue = false;
@@ -1412,7 +1436,7 @@ void IndexingThread::doWork(void)
 
 		if (pFilter != NULL)
 		{
-			// We may able to feed the document directly to the filter
+			// We may be able to feed the document directly to the filter
 			if (((pFilter->is_data_input_ok(Dijon::Filter::DOCUMENT_FILE_NAME) == true) &&
 				(thisUrl.getProtocol() == "file")) ||
 				((pFilter->is_data_input_ok(Dijon::Filter::DOCUMENT_URI) == true) &&
@@ -2149,7 +2173,7 @@ bool DirectoryScannerThread::scanEntry(const string &entryName,
 
 		// If symlinks are followed, check if this symlink is blacklisted
 		if ((m_followSymLinks == false) ||
-			(PinotSettings::getInstance().isBlackListed(entryName) == false))
+			(PinotSettings::getInstance().isBlackListed(entryName) == true))
 		{
 #ifdef DEBUG
 			cout << "DirectoryScannerThread::scanEntry: skipped symlink " << entryName << endl;
