@@ -115,6 +115,42 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 				return true;
 			}
 
+			// Does it end with a dot ?
+			if (term[term.length() - 1] == '.')
+			{
+				bool foundNonDot = false;
+
+				string::size_type pos = term.length() - 1;
+				while (pos >= 0)
+				{
+					if (term[pos] != '.')
+					{
+						foundNonDot = true;
+
+						// Any dot before that ?
+						if ((pos == 0) ||
+							(term.find_last_of(".", pos - 1) == string::npos))
+						{
+							// No, all dots are at the end, trim them
+							term.erase(pos + 1);
+						}
+						// Else, it's probably an acronym
+						break;
+					}
+
+					if (pos == 0)
+					{
+						break;
+					}
+					--pos;
+				}
+
+				if (foundNonDot == false)
+				{
+					// It's all dots !
+					return true;
+				}
+			}
 			m_doc.add_posting(m_prefix + XapianDatabase::limitTermLength(term), m_termPos);
 
 			// Is this CJKV ?
@@ -149,6 +185,44 @@ class TokensIndexer : public Dijon::CJKVTokenizer::TokensHandler
 #endif
 				}
 
+				// Does it include dots ?
+				string::size_type dotPos = term.find('.');
+				if (dotPos != string::npos)
+				{
+					string::size_type startPos = 0;
+					bool addRemainder = true;
+
+#ifdef DEBUG
+					cout << "TokensIndexer::handle_token: found dots in " << term << endl;
+#endif
+					while (dotPos != string::npos)
+					{
+						string component(term.substr(startPos, dotPos - startPos));
+
+						if (component.empty() == false)
+						{
+							m_doc.add_posting(m_prefix + XapianDatabase::limitTermLength(component), m_termPos);
+							++m_termPos;
+						}
+
+						// Next
+						if (dotPos == term.length() - 1)
+						{
+							addRemainder = false;
+							break;
+						}
+						startPos = dotPos + 1;
+						dotPos = term.find('.', startPos);
+					}
+
+					if (addRemainder == true)
+					{
+						string lastComponent(term.substr(startPos));
+
+						m_doc.add_posting(m_prefix + XapianDatabase::limitTermLength(lastComponent), m_termPos);
+					}
+				}
+
 				addSpelling = m_doSpelling;
 				++m_termPos;
 				m_nGramCount = 0;
