@@ -116,7 +116,7 @@ mainWindow::ExpandSet::~ExpandSet()
 }
 
 mainWindow::InternalState::InternalState(mainWindow *pWindow) :
-	ThreadsManager(PinotSettings::getInstance().m_docsIndexLocation, 2, 60, true),
+	ThreadsManager(PinotSettings::getInstance().m_docsIndexLocation, 60, true),
 	m_liveQueryLength(0),
 	m_currentPage(0),
 	m_browsingIndex(false)
@@ -141,8 +141,22 @@ mainWindow::mainWindow() :
 	m_pFindMenu(NULL),
 	m_pSettingsMonitor(MonitorFactory::getMonitor()),
 	m_pSettingsHandler(NULL),
-	m_state(this)
+	m_state(this),
+	m_maxResultsCount(10)
 {
+	// Override the number of query results ?
+	char *pEnvVar = getenv("PINOT_MAXIMUM_QUERY_RESULTS");
+	if ((pEnvVar != NULL) &&
+		(strlen(pEnvVar) > 0))
+	{
+		int threadsNum = atoi(pEnvVar);
+
+		if (threadsNum > 0)
+		{
+			m_maxResultsCount = (unsigned int)threadsNum;
+		}
+	}
+
 	// Reposition and resize the window
 	// Make sure the coordinates and sizes make sense
 	if ((m_settings.m_xPos >= 0) &&
@@ -1482,10 +1496,10 @@ void mainWindow::on_thread_end(WorkerThread *pThread)
 
 		// Suggest the correction to the user
 		if ((pResultsPage != NULL) &&
-			(wasCorrected == true))
+			(wasCorrected == true) &&
+			(pResultsPage->appendSuggestion(queryProps.getFreeQuery()) == true))
 		{
 			pResultsPage->getSuggestSignal().connect(sigc::mem_fun(*this, &mainWindow::on_suggestQueryButton_clicked));
-			pResultsPage->appendSuggestion(queryProps.getFreeQuery());
 		}
 
 		// Now that results are displayed, go ahead and index documents
@@ -2586,7 +2600,7 @@ void mainWindow::on_about_activate()
 
 	aboutBox.set_comments(_("A metasearch tool for the Free Desktop") + string(".\n") +
 		_("Search the Web and your documents !"));
-	aboutBox.set_copyright("(C) 2005-2010 Fabrice Colin");
+	aboutBox.set_copyright("(C) 2005-2011 Fabrice Colin");
 	aboutBox.set_name("Pinot");
 	aboutBox.set_version(VERSION);
 	aboutBox.set_website("http://pinot.berlios.de/");
@@ -2832,6 +2846,8 @@ void mainWindow::on_findButton_clicked()
 {
 	QueryProperties queryProps(_("Live query"), liveQueryEntry->get_text());
 
+	queryProps.setMaximumResultsCount(m_maxResultsCount);
+
 	run_search(queryProps);
 }
 
@@ -3001,14 +3017,10 @@ bool mainWindow::on_mainWindow_delete_event(GdkEventAny *ev)
 		{
 			return true;
 		}
+	}
 
-		m_state.disconnect();
-		m_state.stop_threads();
-	}
-	else
-	{
-		m_state.disconnect();
-	}
+	m_state.disconnect();
+	m_state.mustQuit(true);
 
 	// Disconnect UI signals
 	m_pageSwitchConnection.disconnect();
@@ -3164,6 +3176,11 @@ void mainWindow::edit_query(QueryProperties &queryProps, bool newQuery)
 		// Backup the current name
 		queryName = queryProps.getName();
 	}
+	else
+	{
+		// Initialize the number of results
+		queryProps.setMaximumResultsCount(m_maxResultsCount);
+	}
 
 	// Edit the query's properties
 	queryDialog queryBox(queryProps);
